@@ -22,6 +22,7 @@ def seas_line_plot(df, fwd=None, **kwargs):
     Given a DataFrame produce a seasonal line plot (x-axis - Jan-Dec, y-axis Yearly lines)
     Can overlay a forward curve on top of this
     """
+    df = df.sort_index()
 
     fig = go.Figure()
     traces = cptr.seas_plot_traces(df, fwd, **kwargs)
@@ -153,6 +154,7 @@ def seas_box_plot(hist, fwd=None, **kwargs):
 
 
 def seas_table_plot(hist, fwd=None):
+    hist = hist.sort_index()
     df = cpu.seas_table(hist, fwd)
 
     colsh = list(df.columns)
@@ -196,7 +198,7 @@ def table_plot(df, **kwargs):
     ]
 
     if isinstance(df.index, pd.DatetimeIndex):  # if index is datetime, format dates
-        df.index = df.index.map(lambda x: x.strftime("%d-%m-%Y"), 1)
+        df.index = df.index.map(lambda x: x.strftime("%d-%m-%Y"), )
     cols.insert(0, df.index)
 
     fig = go.Figure(
@@ -639,6 +641,7 @@ def reindex_year_line_subplot(rows, cols, dfs, **kwargs):
 
 def line_plot(df, fwd=None, **kwargs):
     fig = go.Figure()
+    kwargs['colyearmap_enabled'] = False # dont enable colyearmap for line plot as it doesn't apply in this context
     res = cptr.line_plot_traces(df, fwd, **kwargs)
     for trace in res:
         fig.add_trace(trace)
